import os
from pypinyin import lazy_pinyin
from datetime import datetime



def main(vcf_file):
    current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')

    open(f'./rimetool_cache/vcf_cache_contacts_extracted_{current_time}.txt', 'w').close()
    open(f'./rimetool_cache/vcf_cache_contacts_without_blank_{current_time}.txt', 'w').close()    

    # 从vcf文件中提取联系人姓名
    with open(vcf_file, 'r') as infile, open(f'./rimetool_cache/vcf_cache_contacts_extracted_{current_time}.txt', 'w') as outfile:
        # 遍历输入文件的每一行

        for line in infile:
            # 检查行是否以'FN:'开头
            if line.startswith('FN:'):
                # 获取'FN:'后面的内容
                content = line[3:]
                # 将内容写入输出文件
                outfile.write(content)


    # 去掉联系人姓名中的空格

    with open(f'./rimetool_cache/vcf_cache_contacts_extracted_{current_time}.txt', 'r') as infile, open(f'./rimetool_cache/vcf_cache_contacts_without_blank_{current_time}.txt', 'w') as outfile:
        # 遍历输入文件的每一行
        for line in infile:
            # 删除行尾的换行符
            line = line.rstrip('\n')
            # 分割行中的单词
            words = line.rsplit(' ', 1)
            # 如果行中有空格
            if len(words) > 1:
                # 将倒数第一个空格后面的内容移动到最前面，并删除这个空格
                new_line = words[1] + words[0] + '\n'
                # 将新的行写入输出文件
                outfile.write(new_line)
            else:
                # 如果行中没有空格，直接将行写入输出文件
                outfile.write(line + '\n')

    # 转化为rime词典格式
    with open(f'./rimetool_cache/vcf_cache_contacts_without_blank_{current_time}.txt', 'r') as infile, open(f'./rimetool_output/vcf_mycontacts.dict.yaml', 'w+') as outfile:
        # 遍历输入文件的每一行
        outfile.write(
			"# 生成工具 https://github.com/whitewatercn/rimetools\n" +
			"# 生成时间 " + current_time + "\n" +
			"---\n"
		)
        for line in infile:
            # 删除行尾的换行符
            line = line.rstrip('\n')
            # 获取行的拼音
            pinyin = ''.join(lazy_pinyin(line))
            # 在行的内容后面加一个tab，然后加上它的拼音，再加一个tab，然后加上数字1
            new_line = line + '\t' + pinyin + '\t1\n'
            # 将新的行写入输出文件
            outfile.write(new_line)
        outfile.seek(0)


if __name__ == "__main__":
    main()


import os
from rimetool.utils import vcf
from rimetool.utils import singleword
import argparse

# import utils.singleword as singleword

def get_args_parser(add_help=True):

	parser = argparse.ArgumentParser(description='rime输入法相关工具', add_help=add_help)
	parser.add_argument('--input-path', required=True, type=str, help='需要处理的文件路径')
	parser.add_argument('--output-path', default='./rimetool_output', type=str, help='输出文件路径')
	parser.add_argument(
		'--tool', 
		required=True,
		choices=[
			'vcf',
		   'singleword',
		   'hello'],
		type=str, 
		help='选择工具')
	
	return parser

def main():
	parser = get_args_parser()
	args = parser.parse_args()
	
	if not os.path.exists('./rimetool_cache'):
		os.makedirs('./rimetool_cache')
	if not os.path.exists('./rimetool_output'):
		os.makedirs('./rimetool_output')

	if args.tool == 'vcf':
		vcf.main(args.input_path)
	elif args.tool == 'singleword':
		singleword.main(args.input_path)
	else:
		print('这里有问题')
	


if __name__ == "__main__":
	# args = get_args_parser().parse_args()
	main()




from datetime import datetime


def main(singleword_file):
	current_time = datetime.now().strftime('%Y-%m-%d_%H-%M-%S')
	with open(singleword_file, 'r') as infile, open(f'./rimetool_output/singleword.dict.yaml', 'w+') as outfile:
		outfile.write(
			"# 生成工具 https://github.com/whitewatercn/rimetools\n" +
			"# 生成时间 " + current_time + "\n" +
			"---\n"
		)
		for line in infile:
			line_without_space = line.replace(' ','').strip()
			new_line = str(line.strip() + '\t' + line_without_space + '\t'+str(1) +'\n' )
			outfile.write(new_line)



if __name__ == "__main__":
	main()


from setuptools import setup, find_packages
from pathlib import Path

setup(
    # 以下为必需参数
    name='rimetool',  # 模块名
    version='0.1.1',  # 当前版本
    description='rime输入法相关工具',  # 简短描述
    packages=find_packages(include=['rimetool', 'rimetool.*']),  # 包含rimetool和rimetool下的所有子包
    
    # 以下均为可选参数
    long_description="rime输入法相关工具",# 长描述
    url='https://github.com/whitewatercn/rimetool', # 主页链接
    author='whitewatercn', # 作者名
    author_email='whitewatercn@outlook.com', # 作者邮箱
    classifiers=[
        'Intended Audience :: Developers', # 模块适用人群
        'Topic :: Software Development :: Build Tools', # 给模块加话题标签

    ],
    keywords=['rime','input method editor tool','python'],  # 模块的关键词，使用空格分割
    install_requires=['pypinyin',
					  'argparse',
					  'click'], # 依赖模块
    python_requires='>=3.0',  # 模块支持的Python版本
    entry_points={  # 新建终端命令并链接到模块函数
        'console_scripts': [
            'rimetool=rimetool.main:main',
        ],
        },
        project_urls={  # 项目相关的额外链接
        'Bug Reports': 'https://github.com/whitewatercn/rimetool/issues',
        'Source': 'https://github.com/whitewatercn/rimetool',
    },
)
